/**
 * This file Copyright (c) 2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.ckeditor;

import static info.magnolia.ui.vaadin.gwt.client.ckeditor.VMagnoliaCKEditorTextEvents.*;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;

import org.apache.commons.lang3.StringUtils;
import org.vaadin.alump.ckeditor.AbstractCKEditorTextField;

import com.vaadin.annotations.JavaScript;
import com.vaadin.server.PaintException;
import com.vaadin.server.PaintTarget;

/**
 * Magnolia 6 - Vaadin 8 extended CKEditorTextField for custom made Magnolia plugins.
 * By default CKEditor wrapper for Vaadin does not allow
 * custom events between CKEditor plugins and server.
 */
@JavaScript({"vaadin://js/ckeditor/ckeditor.js", "vaadin-save-plugin.js"})
public class MagnoliaCKEditorTextField extends AbstractCKEditorTextField implements MagnoliaCKEditorTextFieldEvents {

    private String fireEvent;
    private String fireEventValue;
    private String[] customEvents;
    private Map<String, String> serverPlugins;
    private List<PluginListener> listeners = new ArrayList<>();
    private MagnoliaCKEditorConfig config;

    public void addListener(PluginListener listener) {
        listeners.add(listener);
    }

    public MagnoliaCKEditorTextField(MagnoliaCKEditorConfig config) {
        super(config);
        this.config = config;
        serverPlugins = config.getExternalPlugins();
        customEvents = config.getListenedEvents();
    }

    @Override
    public void changeVariables(Object source, Map<String, Object> variables) {
        super.changeVariables(source, variables);

        Optional.ofNullable(config).ifPresent(c -> {
            // See if client sends events
            Arrays.stream(c.getListenedEvents())
                    .filter(Objects::nonNull)
                    .forEach(eventName -> {
                        final String eventNameResolved = VAR_EVENT_PREFIX + eventName;
                        if (variables.containsKey(eventNameResolved)) {
                            listeners.forEach(l -> l.onPluginEvent(eventName, variables.get(eventNameResolved).toString()));
                        }
                    });
        });
    }
    @Override
    public void firePluginEvent(String event, String value) {
        fireEvent = event;
        fireEventValue = value;
        markAsDirty();
    }

    @Override
    public void paintContent(PaintTarget target) throws PaintException {
        super.paintContent(target);

        if (serverPlugins != null) {
            target.addAttribute(VAR_SERVERPLUGINS, serverPlugins);
        }

        // tell client that server is interested of these events
        if (customEvents != null) {
            target.addAttribute(VAR_EVENTNAMES, customEvents);
        }

        // send event to plugin
        if (fireEvent != null && fireEventValue != null) {
            target.addAttribute(VAR_FIRE_PLUGIN_EVENT, fireEvent);
            target.addAttribute(VAR_FIRE_PLUGIN_EVENT_VALUE, fireEventValue);
            fireEvent = null;
            fireEventValue = null;
        }
    }

    @Override
    public String getEmptyValue() {
        return "";
    }

    @Override
    public void setHeight(float height, Unit unit) {
        super.setHeight(height, unit);
    }

    @Override
    public boolean isEmpty() {
        return StringUtils.isEmpty(getValue());
    }
}