/**
 * This file Copyright (c) 2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.ckeditor;

/**
 * Magnolia/CKEditor text field events interface.
 */
public interface MagnoliaCKEditorTextFieldEvents {

    /**
     * Event is transmitted from server to client when a link has been selected.
     */
    String EVENT_SEND_MAGNOLIA_LINK = "mgnlLinkSelected";

    /**
     * Event is transmitted from server to client when a link dialog has been
     * canceled or an exception has occurred. In case of exception
     * the event will carry the error message.
     */
    String EVENT_CANCEL_LINK = "mgnlLinkCancel";

    /**
     * Event is transmitted from client to server when a user requests a link dialog.
     * Event carries an optional link that should be treated as default link value.
     */
    String EVENT_GET_MAGNOLIA_LINK = "mgnlGetLink";

    String EVENT_EXPAND_TO_DIALOG = "mgnlExpandToDialog";

    /**
     * Send event to CKEditor instance.
     *
     * @param event Event name that plugin can attach with: editor.on('event', function(e) {...});
     * @param value Additional event data. Plugin can access this by e.data
     */
    void firePluginEvent(String event, String value);

    /**
     * Send event to CKEditor instance. Only event. No additional event data.
     */
    default void firePluginEvent(String event) {
        firePluginEvent(event, "");
    }

    /**
     * Event handler listener for plugin connectivity.
     */
    interface PluginListener {
        void onPluginEvent(String eventName, String value);
    }

    void addListener(PluginListener listener);
}
