/**
 * This file Copyright (c) 2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.extension;

import info.magnolia.ui.vaadin.gwt.client.extension.CloseIconRpc;

import java.io.Serializable;

import com.vaadin.server.AbstractExtension;
import com.vaadin.ui.TabSheet;

/**
 * The {@link CloseIcon} is a Vaadin {@link com.vaadin.server.Extension Extension} for Vaadin {@link TabSheet TabSheets}.
 *
 * <p>It merely adds a close icon to the top-right corner,
 * and leaves the actual closing behavior to implementation, through the {@link CloseHandler}.
 */
public class CloseIcon extends AbstractExtension {

    CloseIcon(TabSheet tabSheet, CloseHandler handler) {
        extend(tabSheet);
        registerRpc((CloseIconRpc) handler::close);
    }

    public static void extend(TabSheet tabSheet, CloseHandler handler) {
        new CloseIcon(tabSheet, handler);
    }

    /**
     * {@link CloseIcon}-enabled components must define what happens when pressing it with a {@link CloseHandler}.
     */
    @FunctionalInterface
    public interface CloseHandler extends Serializable {
        void close();
    }
}