/**
 * This file Copyright (c) 2019 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.extension;

import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Stream;

import com.vaadin.annotations.JavaScript;
import com.vaadin.server.AbstractClientConnector;
import com.vaadin.server.AbstractJavaScriptExtension;
import com.vaadin.ui.Window;

/**
 * Adds a "light" css class to the curtain of the plain Vaadin's {@link Window} so that its background is transparent.
 * <p>Makes the Window resize its height based on its contents.
 */
@JavaScript("resurfaced_window_connector.js")
public class ResurfacedWindow extends AbstractJavaScriptExtension {

    private ResurfacedWindow(Window window) {
        addDoOnWidthToggleFunction(window);
    }

    public static ResurfacedWindow extend(Window target) {
        ResurfacedWindow resurfacedWindow = new ResurfacedWindow(target);
        resurfacedWindow.extend((AbstractClientConnector) target);
        return resurfacedWindow;
    }

    private void addDoOnWidthToggleFunction(Window window) {
        final String originalWidthStyle = Stream.of(window.getStyleName().split(" "))
                                                          .filter(style -> style.matches("small|medium|wide"))
                                                          .findFirst()
                                                          .orElse("medium");
        if (originalWidthStyle.equals("wide")) {
            return; // There is no expand option for a dialog which has `wide` style originally.
        }
        final AtomicReference<String> currentSwitchStyle = new AtomicReference<>(originalWidthStyle);
        addFunction("doOnWidthToggle", args -> {
            String switchToStyle;
            switch (currentSwitchStyle.get()) {
            case "small":
                switchToStyle = "medium";
                break;
            case "medium":
                switchToStyle = "wide";
                break;
            case "wide":
            default:
                switchToStyle = originalWidthStyle;
                break;
            }
            window.setStyleName(window.getStyleName().replace(currentSwitchStyle.get(),switchToStyle));
            currentSwitchStyle.set(switchToStyle);
        });
    }

}
