info_magnolia_ui_vaadin_extension_ResurfacedWindow = function() {
    const dialog = this.getElement(this.getParentId());
    const dialogContents = dialog.querySelector('.v-window.dialog .v-window-contents');

    this.onStateChange = function () {
        if (dialog && dialog.classList.contains('light')) {
            const curtain = dialog.parentNode.querySelector('.v-window-modalitycurtain');
            if (curtain) {
                curtain.classList.add("light");
            }
        }
    }

    const dialogHeader = dialog.querySelector('.v-window-outerheader');
    if (!dialog.classList.contains('wide')) {
        dialogHeader.appendChild(createWidthToggleBox(this));
    }

    const dialogFooterHeaderHeightPx = dialog.querySelector('.dialog .actions').clientHeight;
    const dialogMarginPx = 30;
    let extrasHeight = (dialogMarginPx * 2) + (dialogFooterHeaderHeightPx * 2);

    // The scrollable content in some cases (actually most) is within a tabpanel as a part of tabsheet. Which is where
    // we exceptionally need to set the overflow style. We need to account for tab list height as well.
    const dialogContentHasTabs = dialogContents.querySelector('.v-tabsheet-tabcontainer');
    if (dialogContentHasTabs) {
        extrasHeight += dialogContentHasTabs.clientHeight;
    }

    const resizeFunction = function () {
        let contentToResize = dialogContents.querySelector('.content');
        if (dialogContentHasTabs) {
            contentToResize = dialogContents.querySelector('div[role="tabpanel"]');
        }
        if (contentToResize) {
            contentToResize.style.maxHeight = window.innerHeight - extrasHeight + 'px';
            contentToResize.style.overflow = 'auto';
        }
    }

    // This resize listener is automatically removed by Vaadin.
    // The listener is triggered on more than just window resize occasions, window.addEventListener("resize"..) does not cover all.
    this.addResizeListener(dialogContents, resizeFunction);

    // The resize listener above was not reliably triggered on browser window resize events. As a workaround,
    // resizeFunction is called also when an event listener on browser window gets triggered.
    window.addEventListener("resize", resizeFunction);
    this.onUnregister = function () {
        window.removeEventListener("resize", resizeFunction);
    };
}

createWidthToggleBox = function (that) {
    const widthToggleBox = document.createElement("div");
    widthToggleBox.classList.add("mgnl-window-widthtogglebox");
    widthToggleBox.setAttribute("role", "button");
    widthToggleBox.setAttribute("aria-label", "width toggle button");
    widthToggleBox.onclick = function () {
        that.doOnWidthToggle();
    }
    return widthToggleBox;
}