/**
 * This file Copyright (c) 2019 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.form.custom;

import org.jsoup.nodes.Attributes;
import org.jsoup.nodes.Element;

import com.vaadin.ui.Component;
import com.vaadin.ui.CustomComponent;
import com.vaadin.ui.Label;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.declarative.DesignAttributeHandler;
import com.vaadin.ui.declarative.DesignContext;

/**
 * This component is a visual element used for grouping one or more form fields.
 */
public class Group extends CustomComponent {

    private Label captionLabel = new Label();
    private VerticalLayout fieldContainer = new VerticalLayout();

    public Group() {
        VerticalLayout root = new VerticalLayout();
        root.setSpacing(false);
        root.setStyleName("group");
        captionLabel.setStyleName("caption-label");
        root.addComponent(captionLabel);
        root.addComponent(fieldContainer);
        fieldContainer.setSpacing(false);
        setCompositionRoot(root);
    }

    public void addComponent(Component c) {
        fieldContainer.addComponent(c);
    }

    @Override
    public void readDesign(Element design, DesignContext designContext) {
        // process default attributes
        super.readDesign(design, designContext);

        // handle children
        for (Element childComponent : design.children()) {
            Component newChild = designContext.readDesign(childComponent);
            addComponent(newChild);
            // handle alignment
            Attributes attr = childComponent.attributes();
            fieldContainer.setComponentAlignment(newChild, DesignAttributeHandler.readAlignment(attr));
        }
    }

    public String getCaption() {
        return captionLabel.getValue();
    }

    public void setCaption(String groupLabel) {
        captionLabel.setValue(groupLabel);
    }

}
