/**
 * This file Copyright (c) 2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.layout;

import static java.util.Collections.emptyList;
import static java.util.stream.Collectors.toList;

import info.magnolia.ui.vaadin.gwt.shared.Range;

import java.util.List;

import com.vaadin.data.provider.DataProvider;
import com.vaadin.data.provider.Query;

/**
 * Component for displaying thumbnails of items.
 *
 * @param <T> item type.
 */
public abstract class LazyThumbnailLayout<T> extends LazyLayout<T> {

    private DataProvider<T, ?> dataProvider;

    protected LazyThumbnailLayout(DataProvider<T, ?> dataProvider) {
        this.dataProvider = dataProvider;
        dataProvider.addDataProviderListener(event -> {
            refresh();
            markAsDirty();
        });
    }

    @Override
    public int size() {
        return dataProvider.size(new Query<>());
    }

    @Override
    protected List<T> fetchItems(Range added) {
        return dataProvider.fetch(new Query<>(added.getStart(), added.getEnd(), emptyList(), null, null)).collect(toList());
    }
}
